@@ -1,3 +1,3 @@
-select SUM(value) "Total_Session_UGA"
+select SUM(value) "Total Session UGA"
 from v$sysstat
 where name = 'session uga memory'
